## Changelog

### v0.10.1
- Update dependency versions.
- Fixed bugs regarding data serialization.
- Performance improvements related to the rendering.

For a complete list of changes, please check the detailed changelog.